@@ -26,18 +26,16 @@ from cymysql.cursors import Cursor
 from cymysql.constants.CLIENT import *
 from cymysql.constants.COMMAND import *
 try:
-    from cymysql.convertersx import escape_item, encoders, decoders
+    from cymysql.convertersx import escape_item
 except ImportError:
-    from cymysql.converters import escape_item, encoders, decoders
+    from cymysql.converters import escape_item
 from cymysql.err import raise_mysql_exception, Warning, Error, \
      InterfaceError, DataError, DatabaseError, OperationalError, \
      IntegrityError, InternalError, NotSupportedError, ProgrammingError
 try:
-    from cymysql.packetx import MysqlPacket, FieldDescriptorPacket, MySQLResult
-    from cymysql.packetx import byte2int, int2byte, pack_int24
+    from cymysql.packetx import read_mysqlpacket, MySQLResult
 except ImportError:
-    from cymysql.packet import MysqlPacket, FieldDescriptorPacket, MySQLResult
-    from cymysql.packet import byte2int, int2byte, pack_int24
+    from cymysql.packet import read_mysqlpacket, MySQLResult
 
 PYTHON3 = sys.version_info[0] > 2
 
@@ -45,6 +43,24 @@ DEBUG = False
 
 DEFAULT_CHARSET = 'utf8'
 
+def byte2int(b):
+    if isinstance(b, int):
+        return b
+    else:
+        return ord(b)
+
+def int2byte(i):
+    if PYTHON3:
+        return bytes([i])
+    else:
+        return chr(i)
+
+def pack_int24(n):
+    if PYTHON3:
+        return bytes([n&0xFF, (n>>8)&0xFF,(n>>16)&0xFF])
+    else:
+        return chr(n&0xFF) + chr((n>>8)&0xFF) + chr((n>>16)&0xFF)
+
 def dump_packet(data):
     
     def is_ascii(data):
@@ -115,7 +131,7 @@ class Connection(object):
     def __init__(self, host="localhost", user=None, passwd="",
                  db=None, port=3306, unix_socket=None,
                  charset='', sql_mode=None,
-                 read_default_file=None, conv=decoders, use_unicode=None,
+                 read_default_file=None, use_unicode=None,
                  client_flag=0, cursorclass=Cursor, init_command=None,
                  connect_timeout=None, ssl=None, read_default_group=None,
                  compress=None, named_pipe=None):
@@ -219,8 +235,6 @@ class Connection(object):
 
         self.messages = []
         self.set_charset(charset)
-        self.encoders = encoders
-        self.decoders = conv
 
         self._result = None
         self.host_info = "Not connected"
@@ -384,15 +398,10 @@ class Connection(object):
         self._get_server_information()
         self._request_authentication()
 
-    def read_packet(self, packet_type=MysqlPacket):
+    def read_packet(self):
       """Read an entire "mysql packet" in its entirety from the network
       and return a MysqlPacket type that represents the results."""
-
-      packet = packet_type(self)
-      _errno, _data = packet.check_error()
-      if _errno:
-        raise_mysql_exception(_data)
-      return packet
+      return read_mysqlpacket(self)
 
     def _read_query_result(self):
         result = MySQLResult(self)
@@ -466,11 +475,8 @@ class Connection(object):
         if DEBUG: dump_packet(data)
 
         self.socket.sendall(data)
+        auth_packet = read_mysqlpacket(self)
 
-        auth_packet = MysqlPacket(self)
-        _errno, _data = auth_packet.check_error()
-        if _errno:
-            raise_mysql_exception(_data)
         if DEBUG: dump_packet(auth_packet.get_all_data())
 
         # if old_passwords is enabled the packet will be 1 byte long and
@@ -495,7 +501,7 @@ class Connection(object):
 
     def _get_server_information(self):
         i = 0
-        packet = MysqlPacket(self)
+        packet = read_mysqlpacket(self)
         data = packet.get_all_data()
 
         if DEBUG: dump_packet(data)
